@@ -315,7 +315,7 @@ class ConvNet(pl.LightningModule):
             width = dims[1]
             x_batch = x_batch.reshape(-1, 1, int(height), int(width))
         elif len(dims) == 3:
-            dims = rearrange_dims(dims=dims, dataformats=self.dataformats)
+            dims = rearrange_dims(dims=dims, in_format=self.dataformats, dataformats="NCHW")
             x_batch = x_batch.reshape(-1, *dims)                
         else:
             raise ValueError(f"Wrong dimension {dims} for the input.")
